@@ -9,12 +9,12 @@ from tracardi_text_classification.plugin import TextClassificationAction
 
 init = {
     "source": {
-        "id": "75b367da-9adc-46c9-a4b2-99087e10e3ff"
+        "id": "e7a3979e-7f31-452b-a571-8ca613de77fb"
     },
     "language": "en",
     "model": "press",
     "title": "payload@title",
-    "text": "payload@text"
+    "text": "{{payload@text}}"
 }
 payload = {
     "title": "iPhone 13 is here",
